import sys
import matplotlib.pyplot as plt
import numpy as np
from matplotlib.mlab import griddata

# load the data
data=np.loadtxt(sys.argv[1]) 

# try to read the header
f=open(sys.argv[1],'r')
header=f.readline()
f.close()
header=header.split(',')
if(data[0,:].size!=len(header)):
  header = ['' for i in range(data[0,:].size)]

# make a list of unique x and y values, which is required by griddata()
xi=np.array([])
for x in data[:,0]:
  if not np.in1d(x,xi):
    xi_new=np.append(xi,x)
    xi=xi_new

yi=np.array([])
for y in data[:,1]:
  if not np.in1d(y,yi):
    yi_new=np.append(yi,y)
    yi=yi_new

# start making the plot
plt.figure(1)

# number of directions
n_dir=data[0,:].size-2

# stop if there are too many viewing directions
if(n_dir>10):
  print "Unable to create the plot because of the number of viewing directions is too large!"
  raise SystemExit

# one subplot for each direction
for i_dir in range(n_dir):
  zi=griddata(data[:,0],data[:,1],data[:,i_dir+2],xi,yi)
  plt.subplot(n_dir,1,i_dir+1)
  plt.pcolor(xi,yi,zi)
  plt.colorbar()
  plt.ylabel(header[1].replace('# ',''))
  plt.text(xi[xi.size/2],yi[yi.size/2],header[i_dir+2].replace('# ',''),size=12,horizontalalignment='center')
  
# add the legend
for ax in plt.gcf().axes:
  try:
    ax.label_outer()
  except:
    pass

# label for x axis
plt.xlabel(header[0].replace('# ',''))

# create the plot
plt.show()

